@@ -1,4 +1,4 @@
-<TeXmacs|1.99.4>
+<TeXmacs|1.99.8>
 
 <style|<tuple|source|std>>
 
@@ -46,7 +46,7 @@
 
   <assign|BibTeX|<macro|<active*|<with|font-shape|small-caps|Bib>T<rsub|<space|-0.4spc><move|<resize|<with|math-level|0|E>||||0.5fn>|0fn|-0.1fn>><space|-0.4spc>X>>>
 
-  <assign|hrule|<macro|<no-indent><tabular|<tformat|<cwith|1|-1|1|-1|cell-tborder|1ln>|<twith|table-width|1par>|<cwith|1|-1|1|-1|cell-vmode|exact>|<cwith|1|-1|1|-1|cell-height|1ln>|<cwith|1|-1|1|-1|cell-lsep|0fn>|<cwith|1|-1|1|-1|cell-rsep|0fn>|<cwith|1|-1|1|-1|cell-bsep|0fn>|<cwith|1|-1|1|-1|cell-tsep|0fn>|<cwith|1|-1|1|-1|cell-vcorrect|n>|<table|<row|<cell|<space|1fn|0ln|1ln>>>>>>>>
+  <assign|old-hrule|<macro|<no-indent><tabular|<tformat|<cwith|1|-1|1|-1|cell-tborder|1ln>|<twith|table-width|1par>|<cwith|1|-1|1|-1|cell-vmode|exact>|<cwith|1|-1|1|-1|cell-height|1ln>|<cwith|1|-1|1|-1|cell-lsep|0fn>|<cwith|1|-1|1|-1|cell-rsep|0fn>|<cwith|1|-1|1|-1|cell-bsep|0fn>|<cwith|1|-1|1|-1|cell-tsep|0fn>|<cwith|1|-1|1|-1|cell-vcorrect|n>|<table|<row|<cell|<space|1fn|0ln|1ln>>>>>>>>
 
   <assign|pre-edit|<macro|body|<with|ornament-color|#ffffc0|ornament-sunny-color|#fff0e0|ornament-shadow-color|#ffc080|ornament-border|1px|ornament-hpadding|2px|ornament-vpadding|2px|<smash|<ornament|<with|color|#4040c0|<arg|body>>>>>>>
 
@@ -159,6 +159,8 @@
 
   <assign|english|<macro|body|<with|language|english|<arg|body>>>>
 
+  <assign|esperanto|<macro|body|<with|language|esperanto|<arg|body>>>>
+
   <assign|finnish|<macro|body|<with|language|finnish|<arg|body>>>>
 
   <assign|french|<macro|body|<with|language|french|<arg|body>>>>
@@ -243,6 +245,14 @@
     </surround>
   </macro>>
 
+  <assign|ultra-compact|<\macro|body>
+    <\surround||<right-flush>>
+      <\with|par-sep|0fn|par-ver-sep|0fn|par-line-sep|0fn|par-par-sep|0fn>
+        <arg|body>
+      </with>
+    </surround>
+  </macro>>
+
   <assign|compact|<\macro|body>
     <\surround||<right-flush>>
       <\with|par-par-sep|0fn>
@@ -251,14 +261,32 @@
     </surround>
   </macro>>
 
-  <assign|ultra-compact|<\macro|body>
+  <assign|compressed|<\macro|body>
     <\surround||<right-flush>>
-      <\with|par-sep|0fn|par-ver-sep|0fn|par-line-sep|0fn|par-par-sep|0fn>
+      <\with|par-par-sep|<times|0.5|<value|par-par-sep>>>
         <arg|body>
       </with>
     </surround>
   </macro>>
 
+  <assign|amplified|<\macro|body>
+    <\surround||<right-flush>>
+      <\with|par-par-sep|<times|1.5|<value|par-par-sep>>>
+        <arg|body>
+      </with>
+    </surround>
+  </macro>>
+
+  <assign|vgroup|<\macro|body>
+    <\surround|<no-break-start>|<no-break-end><right-flush>>
+      <\with|par-min-penalty|100000000>
+        <arg|body>
+      </with>
+    </surround>
+  </macro>>
+
+  <assign|indivisible|<value|vgroup>>
+
   \;
 
   <assign|center|<macro|body|<with|par-mode|center|<arg|body>>>>
@@ -293,6 +321,10 @@
 
   <assign|wide-block|<macro|body|<tformat|<twith|table-width|1par>|<twith|table-hmode|exact>|<twith|table-block|yes>|<cwith|1|-1|1|-1|cell-hyphen|t>|<cwith|1|-1|1|-1|cell-hpart|0.001>|<cwith|1|-1|1|-1|cell-rborder|1ln>|<cwith|1|-1|1|-1|cell-bborder|1ln>|<cwith|1|1|1|-1|cell-tborder|1ln>|<cwith|1|-1|1|1|cell-lborder|1ln>|<arg|body>>>>
 
+  <assign|par-block|<macro|body|<tabular|<tformat|<twith|table-width|1par>|<twith|table-hmode|exact>|<cwith|1|1|1|1|cell-hyphen|t>|<cwith|1|1|1|1|cell-lsep|0spc>|<cwith|1|1|1|1|cell-rsep|0spc>|<table|<row|<\cell>
+    <arg|body>
+  </cell>>>>>>>
+
   <\active*>
     <\src-comment>
       Transparency.
@@ -317,6 +349,8 @@
 
   <assign|vphantom|<macro|body|<hresize|<phantom|<arg|body>>|0em|0em>>>
 
+  <assign|concealed|<macro|body|>>
+
   <\active*>
     <\src-comment>
       Adjusting the sizes of boxes.
@@ -343,6 +377,8 @@
 
   <assign|extend|<macro|body|left|bottom|right|top|<style-with|src-compact|none|<resize|<arg|body>|<if|<equal|<arg|left>|>|1l|<minimum|1l|<arg|left>>>|<if|<equal|<arg|bottom>|>|1b|<minimum|1b|<arg|bottom>>>|<if|<equal|<arg|right>|>|1r|<maximum|1r|<arg|right>>>|<if|<equal|<arg|top>|>|1t|<maximum|1t|<arg|top>>>>>>>
 
+  <drd-props|extend|arity|5|accessible|0|length|1|length|2|length|3|length|4>
+
   <assign|extend-right|<macro|body|right|<resize|<arg|body>|||<maximum|1r|<arg|right>>|>>>
 
   <assign|swell|<macro|body|<resize|<arg|body>||<minimum|1b|1fnbot>||<maximum|1t|1fntop>>>>
@@ -388,23 +424,49 @@
 
   <drd-props|underline|with-like|yes|arity|1|accessible|all>
 
-  <assign|strike-through|<macro|body|<quasi|<style-with|src-compact|none|<datoms|<macro|x|<with|color|<unquote|<value|color>>|<repeat|<arg|x>|<resize|-|<plus|1l|0.1fn>||<plus|1r|-0.1fn>|>>>>|<arg|body>>>>>>
+  <assign|stressed-color|black>
+
+  <assign|stressed-distance|0.2fn>
+
+  <assign|stressed|<macro|body|<quasi|<style-with|src-compact|none|<datoms|<macro|x|<with|color|<value|stressed-color>|<repeat|<with|color|<unquote|<value|color>>|<arg|x>>|<move|<resize|-|<plus|0.6667l|0.3333r>||<plus|0.3333l|0.6667r>|>||<minus|-0.5ex|<value|stressed-distance>>>>>>|<arg|body>>>>>>
+
+  <drd-props|stressed|with-like|yes|arity|1|accessible|all>
+
+  <assign|strike-through|<macro|body|<quasi|<style-with|src-compact|none|<datoms|<macro|x|<with|color|<unquote|<value|color>>|<repeat|<arg|x>|<resize|-|<plus|0.6667l|0.3333r>||<plus|0.3333l|0.6667r>|>>>>|<arg|body>>>>>>
 
   <drd-props|strike-through|with-like|yes|arity|1|accessible|all>
 
+  <assign|hrule|<macro|<strike-through|<htab|5mm>>>>
+
   <assign|repeat-through|<macro|what|body|<quasi|<style-with|src-compact|none|<datoms|<macro|x|<repeat|<arg|x>|<unquote|<arg|what>>>>|<arg|body>>>>>>
 
   <drd-props|repeat-through|arity|2|accessible|1>
 
+  \;
+
   <assign|deleted-color|red>
 
   <assign|deleted|<macro|body|<repeat-through|<with|color|<value|deleted-color>|/>|<arg|body>>>>
 
+  <drd-props|deleted|with-like|yes|arity|1|accessible|all>
+
+  \;
+
   <assign|fill-out-color|black>
 
   <assign|fill-out-distance|0.2fn>
 
-  <assign|fill-out|<macro|body|<repeat-through|<with|color|<value|fill-out-color>|<move|.||<minus|<value|fill-out-distance>>>>|<arg|body>>>>
+  <assign|fill-out-hspace|0fn>
+
+  <assign|fill-out|<macro|body|<repeat-through|<with|color|<value|fill-out-color>|<move|.||<minus|<value|fill-out-distance>>><hspace|<value|fill-out-hspace>>>|<arg|body>>>>
+
+  <assign|fill-out*|<macro|body|<fill-out|<arg|body><htab|5mm>>>>
+
+  <assign|fill-dots|<macro|<fill-out|<htab|5mm>>>>
+
+  <drd-props|fill-out|with-like|yes|arity|1|accessible|all>
+
+  \;
 
   <assign|marked-color|yellow>
 
@@ -412,10 +474,18 @@
 
   <assign|marked|<macro|body|<style-with|src-compact|none|<datoms|<macro|x|<resize|<tabular|<tformat|<cwith|1|1|1|1|cell-background|<value|marked-color>>|<cwith|1|1|1|1|cell-lsep|<value|marked-padding>>|<cwith|1|1|1|1|cell-rsep|<value|marked-padding>>|<cwith|1|1|1|1|cell-bsep|<value|marked-padding>>|<cwith|1|1|1|1|cell-tsep|<value|marked-padding>>|<table|<row|<cell|<arg|x>>>>>>|<plus|1l|<value|marked-padding>>|<plus|1b|<value|marked-padding>>|<minus|1r|<value|marked-padding>>|<minus|1t|<value|marked-padding>>>>|<arg|body>>>>>
 
+  <drd-props|marked|with-like|yes|arity|1|accessible|all>
+
+  \;
+
   <assign|todo|<macro|body|<with|color|dark
   red|<style-with|src-compact|none|<datoms|<macro|x|<resize|<tabular|<tformat|<cwith|1|1|1|1|cell-background|pastel
   red>|<cwith|1|1|1|1|cell-lsep|0fn>|<cwith|1|1|1|1|cell-rsep|0fn>|<cwith|1|1|1|1|cell-bsep|<value|marked-padding>>|<cwith|1|1|1|1|cell-tsep|<value|marked-padding>>|<table|<row|<cell|<arg|x>>>>>>|<plus|1l|0fn>|<plus|1b|<value|marked-padding>>|<minus|1r|0fn>|<minus|1t|<value|marked-padding>>>>|[<arg|body>]>>>>>
 
+  <assign|todo*|<macro|body|<with|color|dark
+  orange|<style-with|src-compact|none|<datoms|<macro|x|<resize|<tabular|<tformat|<cwith|1|1|1|1|cell-background|pastel
+  orange>|<cwith|1|1|1|1|cell-lsep|0fn>|<cwith|1|1|1|1|cell-rsep|0fn>|<cwith|1|1|1|1|cell-bsep|<value|marked-padding>>|<cwith|1|1|1|1|cell-tsep|<value|marked-padding>>|<table|<row|<cell|<arg|x>>>>>>|<plus|1l|0fn>|<plus|1b|<value|marked-padding>>|<minus|1r|0fn>|<minus|1t|<value|marked-padding>>>>|[<arg|body>]>>>>>
+
   <\active*>
     <\src-comment>
       Marginal notes.
@@ -472,6 +542,64 @@
   yellow|<tabular*|<tformat|<table|<row|<cell|<small|<with|font-family|tt|<arg|dest>>>>>|<row|<cell|<arg|width>
   <math|\<times\>> <arg|height>>>>>>>>>>
 
+  <\active*>
+    <\src-comment>
+      Poor man font effects.
+    </src-comment>
+  </active*>
+
+  <assign|add-font-effect|<macro|prop|val|body|<with|font-effects|<merge|<value|font-effects>|<if|<equal|<value|font-effects>|>||,>|<arg|prop>|=|<arg|val>>|<arg|body>>>>
+
+  \;
+
+  <assign|embold-strength|2>
+
+  <assign|embbb-strength|3>
+
+  <assign|slanted-slope|0.25>
+
+  <assign|hmagnified-factor|1.5>
+
+  <assign|vmagnified-factor|1.5>
+
+  <assign|condensed-factor|0.8>
+
+  <assign|extended-factor|1.2>
+
+  <assign|degraded-threshold|0.667>
+
+  <assign|degraded-frequency|1.0>
+
+  <assign|distorted-strength|0.5>
+
+  <assign|distorted-frequency|1.0>
+
+  <assign|gnawed-strength|0.6>
+
+  <assign|gnawed-frequency|1.0>
+
+  \;
+
+  <assign|embold|<macro|body|<add-font-effect|bold|<value|embold-strength>|<arg|body>>>>
+
+  <assign|embbb|<macro|body|<add-font-effect|bbb|<value|embbb-strength>|<arg|body>>>>
+
+  <assign|slanted|<macro|body|<add-font-effect|slant|<value|slanted-slope>|<arg|body>>>>
+
+  <assign|hmagnified|<macro|body|<add-font-effect|hmagnify|<value|hmagnified-factor>|<arg|body>>>>
+
+  <assign|vmagnified|<macro|body|<add-font-effect|vmagnify|<value|vmagnified-factor>|<arg|body>>>>
+
+  <assign|condensed|<macro|body|<add-font-effect|hextended|<value|condensed-factor>|<arg|body>>>>
+
+  <assign|extended|<macro|body|<add-font-effect|hextended|<value|extended-factor>|<arg|body>>>>
+
+  <assign|degraded|<macro|body|<add-font-effect|degraded|<merge|<value|degraded-threshold>|;|<value|degraded-frequency>>|<arg|body>>>>
+
+  <assign|distorted|<macro|body|<add-font-effect|distorted|<merge|<value|distorted-strength>|;|<value|distorted-frequency>>|<arg|body>>>>
+
+  <assign|gnawed|<macro|body|<add-font-effect|gnawed|<merge|<value|gnawed-strength>|;|<value|gnawed-frequency>>|<arg|body>>>>
+
   <\active*>
     <\src-comment>
       Miscellaneous.
@@ -483,6 +611,16 @@
   <assign|slink|<macro|body|<hlink|<with|font-family|tt|language|verbatim|<arg|body>>|<arg|body>>>>
 
   <assign|square|<macro|x|<times|<arg|x>|<arg|x>>>>
+
+  <assign|text-dots-sep|0.3333spc>
+
+  <assign|text-spc|<macro|<hspace|<value|text-dots-sep>>>>
+
+  <assign|text-dots|<macro|<text-spc>.<text-spc>.<text-spc>.<text-spc>>>
+
+  <assign|indent-par-first|1.5fn>
+
+  <assign|padded-par-par-sep|0.6666fn>
 </body>
 
 <\initial>
