@@ -111,6 +111,8 @@
   (nasympasymp "{\\not\\asymp\\!\\!\\!\\!\\!\\!-}")
   (simsim "{\\approx\\!\\!\\!\\!\\!\\!-}")
   (nsimsim "{\\not\\approx\\!\\!\\!\\!\\!\\!-}")
+  (triplesim "{\\approx\\!\\!\\!\\!\\!\\!\\sim}")
+  (ntriplesim "{\\not\\approx\\!\\!\\!\\!\\!\\!\\sim}")
   (precprec "\\prec\\!\\!\\!\\prec")
   (precpreceq "\\preceq\\!\\!\\!\\preceq")
   (precprecprec "\\prec\\!\\!\\!\\prec\\!\\!\\!\\prec")
@@ -147,11 +149,25 @@
   (Tau "\\mathrm{T}")
   (Zeta "\\mathrm{Z}")
 
+  ;; symbols from mathabx
+  ;; NOTE: we avoid using the mathabx package because it tends
+  ;; to be badly installed and incompatible with certain styles
+  (divides "\\mathrel{|}")
+  (ndivides "\\mathrel{\\nmid}")
+  (asterisk "\\mathord{*}")
+  (npreccurlyeq (!annotate "\\mathrel{\\not\\preccurlyeq}" (preccurlyeq)))
+  (dottimes "\\mathbin{\\dot{\\times}}")
+  (nequiv "\\mathrel{\\not\\equiv}")
+  (precdot "\\mathrel{\\prec\\!\\!\\cdot")
+  
   ;; other extra symbols
   (exterior "\\wedge")
   (Exists "\\exists")
   (bigintwl "\\int")
   (bigointwl "\\oint")
+  (of ":")
+  (suchthat ":")
+  (barsuchthat "|")
   (point ".")
   (cdummy "\\cdot")
   (comma "{,}")
@@ -166,6 +182,9 @@
   (nni "\\not\\ni")
   (notni "\\not\\ni")
   (nleadsto (!annotate "\\not\\leadsto" (leadsto)))
+  (dotminus "\\mathaccent95{-}")
+  (dotpm "\\mathaccent95{\\pm}")
+  (dotmp "\\mathaccent95{\\mp}")
   (dotamalg "\\mathaccent95{\\amalg}")
   (dotoplus "\\mathaccent95{\\oplus}")
   (dototimes "\\mathaccent95{\\otimes}")
@@ -190,10 +209,17 @@
   (minusassign "-\\!\\!=")
   (timesassign "\times\\!\\!=")
   (overassign "/\\!\\!=")
+  (backassign "=:")
   (lflux "\\ll")
   (gflux "\\gg")
   (colons "\\,:\\,")
   (transtype "\\,:\\!!>")
+  (lebar (mathrel (Yleft)))
+  (gebar (mathrel (Yright)))
+  (leangle (mathrel (angle)))
+  (geangle (mathrel (!group (mbox (reflectbox (!math (angle)))))))
+  (leqangle (mathrel (substack (!append (angle) "\\\\" "-"))))
+  (geqangle (mathrel (!group (mbox (reflectbox (!math (substack (!append (angle) "\\\\" "-"))))))))
   (udots "{\\mathinner{\\mskip1mu\\raise1pt\\vbox{\\kern7pt\\hbox{.}}\\mskip2mu\\raise4pt\\hbox{.}\\mskip2mu\\raise7pt\\hbox{.}\\mskip1mu}}")
   (subsetsim (underset (sim) (subset)))
   (supsetsim (underset (sim) (supset)))
@@ -210,7 +236,6 @@
   ;; Nullary macros
   (tmunsc "\\_")
   (emdash "---")
-  (tmhrule "\\noindent\\rule[0.3\\baselineskip]{\\textwidth}{0.4pt}")
   (tmat "\\symbol{\"40}")
   (tmbsl "\\ensuremath{\\backslash}")
   (tmdummy "$\\mbox{}$")
@@ -359,6 +384,8 @@
   (ontop (genfrac "" "" "0pt" "" 1 2))
   (subindex (index (!append 1 "!" 2)))
   (renderfootnote (footnotetext (!append (tmrsup 1) " " 2)))
+  (tmlinenumber (!append (custombinding 1)
+                         (tmlinenote (footnotesize 1) 2 "0cm")))
 
   ;; Ternary macros
   (tmsession (!group (!append (tt) 3)))
@@ -376,6 +403,12 @@
    (trivlist (!append (item (!option (!append (color "rgb:black,10;red,9;green,4;yellow,2") 1)))
 		      (mbox "") (!group (!append (color "blue!50!black") 2))
 		      (item (!option "")) (mbox "") 3)))
+  (tmlinenote
+   (!append (tmdummy)
+            (marginpar (adjustbox
+                        (!append "right=0cm, lap=" 2
+                                 "-\\textwidth-\\marginparsep, raise=" 3)
+                        1))))
   (subsubindex (index (!append 1 "!" 2 "!" 3)))
   (tmref 1)
   (glossaryentry (!append (item (!option (!append 1 (hfill)))) 2 (dotfill) 3))
@@ -547,6 +580,13 @@
   (mho
    (!append
     "\\renewcommand{\\mho}{\\mbox{\\rotatebox[origin=c]{180}{$\\omega$}}}"))
+  (custombinding
+   (!append
+    "\\newcounter{tmcounter}\n"
+    "\\newcommand{\\custombinding}[1]{%\n"
+    "  \\setcounter{tmcounter}{#1}%\n"
+    "  \\addtocounter{tmcounter}{-1}%\n"
+    "  \\refstepcounter{tmcounter}}\n"))
   (tmfloat
    (!append
     (!ignore (ifthenelse) (captionof) (widthof))
