@@ -34,24 +34,36 @@
         (include-list prj t))
       (list)))
 
-(tm-define (project-menu)
+(tm-define (main-project-entry)
+  (buffer-list-menu (list (project-get))))
+
+(tm-define (project-list-menu)
   (buffer-list-menu (project-file-list)))
 
+(menu-bind project-menu
+  (if (== (project-get) (current-buffer))
+      (link preamble-menu))
+  (if (!= (project-get) (current-buffer))
+      (link main-project-entry))
+  ---    
+  (link project-list-menu))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Document style
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (menu-bind document-style-menu
-  ("No style" (set-no-style))
-  ---
   (link style-menu)
   ---
+  ("No style" (set-no-style))
+  ("Edit style" (edit-style-source))
   ("Other style" (interactive set-main-style))
   ---
   (group "Customizations")
   (with l (get-style-list)
     (for (pack (if (null? l) l (cdr l)))
       (-> (eval (upcase-first pack))
+          ("Edit package" (edit-package-source pack))
           ("Remove package" (remove-style-package pack)))))
   (-> "Add package"
       (link toggle-package-menu)
@@ -117,7 +129,7 @@
 
 (menu-bind document-font-menu
   (-> "Text font"
-      ("Default" (init-default "font"))
+      ("Default" (init-default "font" "math-font" "prg-font"))
       ---
       ("Concrete" (init-env "font" "concrete"))
       (if (url-exists-in-tex? "pnr10.mf")
@@ -134,6 +146,8 @@
       ("Palatino" (init-env "font" "palatino"))
       ("Times" (init-env "font" "times"))
       ---
+      (if (font-exists-in-tt? "texgyrebonum-regular")
+          ("Bonum" (init-env "font" "bonum")))
       (if (font-exists-in-tt? "DejaVuSerif")
           ("Dejavu" (init-env "font" "dejavu")))
       ("Lucida" (init-env "font" "x-lucida"))
@@ -141,6 +155,8 @@
           ("Luxi" (init-env "font" "luxi")))
       (if (font-exists-in-tt? "texgyrepagella-regular")
           ("Pagella" (init-env "font" "pagella")))
+      (if (font-exists-in-tt? "texgyreschola-regular")
+          ("Schola" (init-env "font" "schola")))
       (if (font-exists-in-tt? "texgyretermes-regular")
           ("Termes" (init-env "font" "termes")))
       ("Utopia" (init-env "font" "x-utopia"))
@@ -220,6 +236,8 @@
           ("Apple symbols" (init-env "math-font" "math-apple")))
       (if (font-exists-in-tt? "Asana-Math")
           ("Asana" (init-env "math-font" "math-asana")))
+      (if (font-exists-in-tt? "texgyrebonum-math")
+          ("Bonum" (init-env "math-font" "math-bonum")))
       ("Concrete" (init-env "math-font" "concrete"))
       (if (font-exists-in-tt? "DejaVuSerif")
           ("Dejavu" (init-env "math-font" "math-dejavu")))
@@ -229,6 +247,8 @@
       (if (font-exists-in-tt? "texgyrepagella-math")
           ("Pagella" (init-env "math-font" "math-pagella")))
       ("Roman" (init-env "math-font" "roman"))
+      (if (font-exists-in-tt? "texgyreschola-math")
+          ("Schola" (init-env "math-font" "math-schola")))
       (if (font-exists-in-tt? "STIX-Regular")
           ("Stix" (init-env "math-font" "math-stix")))
       (if (font-exists-in-tt? "texgyretermes-math")
@@ -283,84 +303,107 @@
 (tm-define (init-default-font)
   (:check-mark "*" test-default-font?)
   (init-default "font")
-  (init-default "math-font"))
-
-(tm-define (test-init-font? val math-val)
-  (== (get-init "font") val))
-
-(tm-define (init-font val math-val)
-  (:check-mark "*" test-init-font?)
-  (init-env "font" val)
-  (init-env "math-font" math-val))
+  (init-default "math-font")
+  (init-default "font-family"))
 
 (menu-bind document-short-chinese-font-menu
   (if (font-exists-in-tt? "AppleGothic")
-      ("Apple Gothic" (init-env "font" "apple-gothic")))
+      ("Apple Gothic" (init-font "apple-gothic")))
   (if (font-exists-in-tt? "FandolSong-Regular")
-      ("FandolSong" (init-env "font" "FandolSong")))
+      ("FandolSong" (init-font "FandolSong")))
   (if (font-exists-in-tt? "fireflysung")
-      ("Fireflysung" (init-env "font" "fireflysung")))
+      ("Fireflysung" (init-font "fireflysung")))
   (if (font-exists-in-tt? "wqy-microhei")
-      ("MicroHei" (init-env "font" "wqy-microhei")))
+      ("MicroHei" (init-font "wqy-microhei")))
   (if (font-exists-in-tt? "MS Mincho")
-      ("MS Mincho" (init-env "font" "ms-mincho")))
+      ("MS Mincho" (init-font "ms-mincho")))
   (if (font-exists-in-tt? "simsun")
-      ("SimSun" (init-env "font" "simsun")))
+      ("SimSun" (init-font "simsun")))
   (if (font-exists-in-tt? "uming")
-      ("UMing" (init-env "font" "uming")))
+      ("UMing" (init-font "uming")))
   (if (font-exists-in-tt? "wqy-zenhei")
-      ("ZenHei" (init-env "font" "wqy-zenhei"))))
+      ("ZenHei" (init-font "wqy-zenhei"))))
 
 (menu-bind document-short-japanese-font-menu
   (if (font-exists-in-tt? "AppleGothic")
-      ("Apple Gothic" (init-env "font" "apple-gothic")))
+      ("Apple Gothic" (init-font "apple-gothic")))
   (if (font-exists-in-tt? "华文细黑")
-      ("HeiTi" (init-env "font" "heiti")))
+      ("HeiTi" (init-font "heiti")))
   (if (font-exists-in-tt? "ヒラギノ明朝 ProN W6")
-      ("Hiragino Kaku" (init-env "font" "kaku")))
+      ("Hiragino Kaku" (init-font "kaku")))
   (if (font-exists-in-tt? "ipam")
-      ("Ipa" (init-env "font" "ipa")))
+      ("Ipa" (init-font "ipa")))
   (if (font-exists-in-tt? "ttf-japanese-gothic")
-      ("Japanese" (init-env "font" "ttf-japanese")))
+      ("Japanese" (init-font "ttf-japanese")))
   (if (font-exists-in-tt? "sazanami-gothic")
-      ("Sazanami" (init-env "font" "sazanami")))
+      ("Sazanami" (init-font "sazanami")))
   (if (font-exists-in-tt? "ukai")
-      ("UKai" (init-env "font" "ukai"))))
+      ("UKai" (init-font "ukai"))))
 
 (menu-bind document-short-korean-font-menu
   (if (font-exists-in-tt? "AppleGothic")
-      ("Apple Gothic" (init-env "font" "apple-gothic")))
+      ("Apple Gothic" (init-font "apple-gothic")))
   (if (font-exists-in-tt? "Batang")
-      ("Batang" (init-env "font" "batang")))
+      ("Batang" (init-font "batang")))
   (if (font-exists-in-tt? "Gulim")
-      ("Gulim" (init-env "font" "gulim")))
+      ("Gulim" (init-font "gulim")))
   (if (font-exists-in-tt? "unbatang")
-      ("Unbatang" (init-env "font" "unbatang"))))
+      ("Unbatang" (init-font "unbatang"))))
 
 (menu-bind document-short-font-menu
   ("Default" (init-default-font))
   ---
-  ("Concrete" (init-font "concrete" "concrete"))
   ("Roman" (init-font "roman" "roman"))
   ("Stix" (init-font "stix" "math-stix"))
-  ---
-  ("Avant Garde" (init-env "font" "avant-garde"))
-  ("Bookman" (init-env "font" "bookman"))
-  ("Courier" (init-env "font" "courier"))
-  ("Helvetica" (init-env "font" "helvetica"))
-  ("NC Schoolbook" (init-env "font" "new-century-schoolbook"))
-  ("Palatino" (init-env "font" "palatino"))
-  ("Times" (init-env "font" "times"))
-  (if (or (font-exists-in-tt? "DejaVuSerif")
+  (if (or (font-exists-in-tt? "texgyrebonum-math")
           (font-exists-in-tt? "texgyrepagella-math")
+          (font-exists-in-tt? "texgyreschola-math")
           (font-exists-in-tt? "texgyretermes-math"))
       ---
-      (if (font-exists-in-tt? "DejaVuSerif")
-          ("Dejavu" (init-font "dejavu" "math-dejavu")))
+      (group "TeX Gyre")
+      (if (font-exists-in-tt? "texgyrebonum-math")
+          ("Bonum" (init-font "bonum" "math-bonum")))
       (if (font-exists-in-tt? "texgyrepagella-math")
           ("Pagella" (init-font "pagella" "math-pagella")))
+      (if (font-exists-in-tt? "texgyreschola-math")
+          ("Schola" (init-font "schola" "math-schola")))
       (if (font-exists-in-tt? "texgyretermes-math")
           ("Termes" (init-font "termes" "math-termes"))))
+  (if (or (font-exists-in-tt? "DejaVuSerif")
+          (font-exists-in-tt? "LinLibertine_R")
+          (font-exists-in-tt? "Optima")
+          (font-exists-in-tt? "Papyrus"))
+      ---
+      (if (font-exists-in-tt? "AmericanTypewriter")
+          ("American Typewriter" (init-font "American Typewriter")))
+      (if (font-exists-in-tt? "Baskerville")
+          ("Baskerville" (init-font "Baskerville")))
+      (if (font-exists-in-tt? "Chalkboard")
+          ("Chalkboard" (init-font "Chalkboard")))
+      (if (font-exists-in-tt? "Chalkduster")
+          ("Chalkduster" (init-font "Chalkduster")))
+      (if (font-exists-in-tt? "Cochin")
+          ("Cochin" (init-font "Cochin")))
+      (if (font-exists-in-tt? "Cuprum-Regular")
+          ("Cuprum" (init-font "Cuprum")))
+      (if (font-exists-in-tt? "DejaVuSerif")
+          ("Dejavu" (init-font "dejavu" "math-dejavu")))
+      (if (font-exists-in-tt? "Didot")
+          ("Didot" (init-font "Didot")))
+      (if (font-exists-in-tt? "Essays1743")
+          ("Essays1743" (init-font "Essays1743")))
+      (if (font-exists-in-tt? "MarkerFelt")
+          ("Marker Felt" (init-font "Marker Felt")))
+      (if (font-exists-in-tt? "meyne_textur")
+          ("Meyne Textur" (init-font "Meyne Textur")))
+      (if (font-exists-in-tt? "LinBiolinum_R")
+          ("Linux Biolinum" (init-font "Linux Biolinum")))
+      (if (font-exists-in-tt? "LinLibertine_R")
+          ("Linux Libertine" (init-font "Linux Libertine")))
+      (if (font-exists-in-tt? "Optima")
+          ("Optima" (init-font "Optima")))
+      (if (font-exists-in-tt? "Papyrus")
+          ("Papyrus" (init-font "Papyrus"))))
   (if (and (supports-chinese?) (== (get-init "language") "chinese"))
       ---
       (link document-short-chinese-font-menu))
@@ -391,7 +434,7 @@
       ("Left aligned" (init-env "par-mode" "left"))
       ("Centered" (init-env "par-mode" "center"))
       ("Right aligned" (init-env "par-mode" "right")))
-  (-> "Hyphenation"
+  (-> "Line breaking"
       ("Default" (init-default "par-hyphen"))
       ---
       ("Normal" (init-env "par-hyphen" "normal"))
@@ -410,9 +453,7 @@
   (-> "Number of columns"
       ("Default" (init-default "par-columns"))
       ---
-      ("1" (init-env "par-columns" "1"))
-      ("2" (init-env "par-columns" "2"))
-      ("3" (init-env "par-columns" "3")))
+      (link document-columns-menu))
   (-> "Advanced"
       (-> "Space stretchability"
           ("Default" (init-default "par-flexibility"))
@@ -465,22 +506,7 @@
   ("Standard 4:3" (init-page-type "4:3"))
   ("Standard 5:4" (init-page-type "5:4")))
 
-(tm-menu (document-page-size-menu)
-  ("Default"
-   (init-default "page-type" "page-width" "page-height")
-   (notify-page-change))
-  ---
-  (if (not (style-has? "beamer-style"))
-      (group "Common formats")
-      (link document-common-page-size-menu))
-  (if (style-has? "beamer-style")
-      (group "Beamer formats")
-      (link document-beamer-page-size-menu))
-  ---
-  (group "Standard formats")
-  (if (style-has? "beamer-style")
-      (-> "Common"
-          (link document-common-page-size-menu)))
+(tm-menu (document-standard-page-formats)
   (-> "A series"
       ("A0" (init-page-type "a0"))
       ("A1" (init-page-type "a1"))
@@ -533,25 +559,66 @@
       ("Note" (init-page-type "note"))
       ("Quarto" (init-page-type "quarto"))
       ("Statement" (init-page-type "statement"))
-      ("Tabloid" (init-page-type "tabloid")))
-  (if (not (style-has? "beamer-style"))
-      (-> "Beamer"
-          (link document-beamer-page-size-menu)))
+      ("Tabloid" (init-page-type "tabloid"))))
+
+(tm-menu (document-page-size-menu)
+  ("Default" (default-page-type))
+  ---
+  (group "Common formats")
+  (link document-common-page-size-menu)
+  ---
+  (group "Standard formats")
+  (link document-standard-page-formats)
+  (-> "Beamer"
+      (link document-beamer-page-size-menu))
+  ---
+  ("Other" (interactive init-page-size)))
+
+(tm-menu (document-page-size-menu)
+  (:require (style-has? "beamer-style"))
+  ("Default" (default-page-type))
+  ---
+  (group "Beamer formats")
+  (link document-beamer-page-size-menu)
+  ---
+  (group "Standard formats")
+  (-> "Common"
+      (link document-common-page-size-menu))
+  (link document-standard-page-formats)
   ---
   ("Other" (interactive init-page-size)))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Number of columns
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(tm-menu (document-columns-menu)
+  ("One column" (init-env "par-columns" "1"))
+  ("Two columns" (init-env "par-columns" "2")))
+  
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; The Document -> Page menu
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
+(menu-bind page-rendering-menu
+  ("Paper" (init-page-rendering "paper"))
+  ("Papyrus" (init-page-rendering "papyrus"))
+  ("Automatic" (init-page-rendering "automatic"))
+  ("Beamer" (init-page-rendering "beamer"))
+  ("Book" (init-page-rendering "book"))
+  ("Panorama" (init-page-rendering "panorama")))
+
+(menu-bind page-layout-menu
+  ("Margins as on paper" (toggle-page-screen-margin))
+  ("Reduced margins" (toggle-reduced-margins))
+  ("Indent paragraphs" (toggle-indent-paragraphs))
+  ("No page numbers" (toggle-no-page-numbers)))
+
 (menu-bind document-page-menu
   (-> "Type"
-      ("Default" (init-default-page-medium))
+      ("Default" (init-default-page-rendering))
       ---
-      ("Paper" (init-page-medium "paper"))
-      ("Papyrus" (init-page-medium "papyrus"))
-      ("Automatic" (init-page-medium "automatic"))
-      ("Beamer" (init-page-medium "beamer")))
+      (link page-rendering-menu))
   (-> "Size"
       (link document-page-size-menu))
   (-> "Orientation"
@@ -647,6 +714,17 @@
 ;; The Document -> Color menu
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
+(define (set-background col)
+  (init-env-tree "bg-color" col))
+
+(define (set-background-pattern name)
+  (when (pair? name) (set! name (car name)))
+  (init-env-tree "bg-color" (tm-pattern name "" "")))
+
+(define (set-background-picture name)
+  (when (pair? name) (set! name (car name)))
+  (init-env-tree "bg-color" (tm-pattern name "100%" "100@")))
+
 (menu-bind document-foreground-color-menu
   ("Default" (init-default "color"))
   ---
@@ -661,8 +739,8 @@
   ---
   (pick-background "" (init-env-tree "bg-color" answer))
   ---
-  ("Palette" (interactive-background
-              (lambda (col) (init-env "bg-color" col)) '()))
+  ("Palette" (interactive-background set-background '()))
+  ("Pattern" (open-pattern-selector set-background "1cm"))
   ("Other" (init-interactive-env "bg-color")))
 
 (menu-bind document-colors-menu
@@ -736,7 +814,8 @@
   ;;(link remove-package-menu)
   ;;---
   ;;("Other" (interactive remove-style-package)))
-  (if (!= (get-init-tree "sectional-short-style") (tree 'macro "false"))
+  (if (and (not (project-attached?))
+           (!= (get-init-tree "sectional-short-style") (tree 'macro "false")))
       (-> "Part" (link document-part-menu)))
   (-> "Source"
       ("Edit source tree" (toggle-preamble))
@@ -749,6 +828,9 @@
   (-> "Paragraph" (link document-paragraph-menu))
   (-> "Page" (link document-page-menu))
   (-> "Metadata" (link document-metadata-menu))
+  (-> "Bibliography"
+      (when (buffer-has-biblio? (current-buffer))
+	("Local entries" (open-biblio))))
   ---
   (-> "Magnification" (link document-magnification-menu))
   (-> "Colors" (link document-colors-menu))
@@ -765,7 +847,8 @@
 (menu-bind compressed-document-menu
   (-> "Style" (link document-style-menu))
   (link document-style-extra-menu)
-  (if (!= (get-init-tree "sectional-short-style") (tree 'macro "false"))
+  (if (and (not (project-attached?))
+           (!= (get-init-tree "sectional-short-style") (tree 'macro "false")))
       (-> "Part" (link document-part-menu)))
   (-> "Source"
       ("Edit source tree" (toggle-preamble))
@@ -779,6 +862,8 @@
   ("Paragraph" (open-document-paragraph-format))
   ("Page" (open-document-page-format))
   ("Metadata" (open-document-metadata))
+  (when (buffer-has-biblio? (current-buffer))
+    ("Bibliography" (open-biblio)))
   ;;("Colors" (open-document-colors))
   ---
   (-> "Magnification" (link document-magnification-menu))
@@ -815,10 +900,12 @@
     (-> (eval (upcase-first (car st)))
         (link style-menu)
         ---
+        ("Edit style" (edit-style-source))
         ("Other style" (interactive set-main-style)))
     (dynamic (focus-style-extra-menu t))
     (for (pack (list-filter (cdr st) (negate hidden-package?)))
       (-> (eval (upcase-first pack))
+          ("Edit package" (edit-package-source pack))
           ("Remove package" (remove-style-package pack)))))
   (-> "Add style package"
       (link add-package-menu)
@@ -830,6 +917,8 @@
         ((== s "1") "One column")
         ((== s "2") "Two columns")
         ((== s "3") "Three columns")
+        ((== s "4") "Four columns")
+        ((== s "5") "Five columns")
         (else (string-append s " columns"))))
 
 (tm-menu (focus-document-menu t)
@@ -838,19 +927,21 @@
       (link document-page-size-menu))
   (-> (eval (string-append (get-init "font-base-size") " pt"))
       (link document-font-base-size-menu))
+  (-> (eval (upcase-first (get-init-page-rendering)))
+      (link page-rendering-menu))
   (-> (eval (upcase-first (get-init "page-orientation")))
       ("Portrait" (init-page-orientation "portrait"))
       ("Landscape" (init-page-orientation "landscape")))
   (-> (eval (number-columns-text (get-init "par-columns")))
-      ("One column" (init-env "par-columns" "1"))
-      ("Two columns" (init-env "par-columns" "2")))
+      (link document-columns-menu))
+  (-> "Layout"
+      (link page-layout-menu))
   (if (and (== (get-preference "experimental encryption") "on")
 	   (!= (get-init "encryption") ""))
-      (=> (balloon (icon "tm_lock_open.xpm") "Encryption")
-	  (link document-encryption-menu)))
+      (-> "Encryption" (link document-encryption-menu)))
   (-> (eval (upcase-first (get-init "language")))
       (link document-language-menu))
-  (-> (eval (upcase-first (get-init "font")))
+  (-> (eval (upcase-first (font-family-main (get-init "font"))))
       (link document-short-font-menu)))
 
 (tm-menu (standard-focus-menu t)
@@ -874,10 +965,12 @@
       (=> (balloon (eval (upcase-first (car st))) "Document style")
           (link style-menu)
           ---
+          ("Edit style" (edit-style-source))
           ("Other style" (interactive set-main-style)))
       (dynamic (focus-style-extra-icons t))
       (for (pack (list-filter (cdr st) (negate hidden-package?)))
         (=> (eval pack)
+            ("Edit package" (edit-package-source pack))
             ("Remove package" (remove-style-package pack)))))
     (=> (balloon (icon "tm_add.xpm") "Add style package")
         (link add-package-menu)
@@ -902,23 +995,21 @@
     (=> (balloon (eval (upcase-first (get-init "page-type")))
                  "Paper size")
         (link document-page-size-menu))
+    (=> (balloon (eval (upcase-first (font-family-main (get-init "font"))))
+                 "Main document font")
+        (link document-short-font-menu))
     (=> (balloon (eval (string-append (get-init "font-base-size") "pt"))
                  "Font size")
         (link document-font-base-size-menu))
-    (=> (balloon (eval (upcase-first (get-init "font")))
-                 "Main document font")
-        (link document-short-font-menu))
     (=> (balloon (icon (eval (current-page-icon))) "Page layout")
         ("Portrait" (init-page-orientation "portrait"))
         ("Landscape" (init-page-orientation "landscape"))
         ---
-        ("One column" (init-env "par-columns" "1"))
-        ("Two columns" (init-env "par-columns" "2"))
+        (link document-columns-menu)
         ---
-        ("Paper" (init-page-medium "paper"))
-        ("Papyrus" (init-page-medium "papyrus"))
-        ("Automatic" (init-page-medium "automatic"))
-        ("Beamer" (init-page-medium "beamer")))
+	(link page-rendering-menu)
+        ---
+        (link page-layout-menu))
     (if (and (== (get-preference "experimental encryption") "on")
 	     (!= (get-init "encryption") ""))
 	(=> (balloon (icon "tm_lock_open.xpm") "Encryption")
