@@ -568,22 +568,36 @@
   (">" "<gtr>")
   ("< /" "<nless>")
   ("> /" "<ngtr>")
+  ("< . ." "<less><cdots><less>")
+  ("> . ." "<gtr><cdots><gtr>")
   ("< =" "<leqslant>")
   ("> =" "<geqslant>")
   ("< = /" "<nleqslant>")
   ("> = /" "<ngeqslant>")
+  ("< = . ." "<leqslant><cdots><leqslant>")
+  ("> = . ." "<geqslant><cdots><geqslant>")
   ("< = var" "<leq>")
   ("> = var" "<geq>")
   ("< = var /" "<nleq>")
   ("> = var /" "<ngeq>")
+  ("< = var . ." "<leq><cdots><leq>")
+  ("> = var . ." "<geq><cdots><geq>")
   ("< <" "<ll>")
   ("< < <" "<lll>")
   ("> >" "<gg>")
   ("> > >" "<ggg>")
+  ("< < . ." "<ll><cdots><ll>")
+  ("< < < . ." "<lll><cdots><lll>")
+  ("> > . ." "<gg><cdots><gg>")
+  ("> > > . ." "<ggg><cdots><ggg>")
   ("< < =" "<lleq>")
   ("< < < =" "<llleq>")
   ("> > =" "<ggeq>")
   ("> > > =" "<gggeq>")
+  ("< < = . ." "<lleq><cdots><lleq>")
+  ("< < < = . ." "<llleq><cdots><llleq>")
+  ("> > = . ." "<ggeq><cdots><ggeq>")
+  ("> > > = . ." "<gggeq><cdots><gggeq>")
   ("< < /" "<nll>")
   ("< < < /" "<nlll>")
   ("> > /" "<ngg>")
@@ -593,9 +607,14 @@
   ("> > = /" "<nggeq>")
   ("> > > = /" "<ngggeq>")
   ("< ." "<lessdot>")
+  ("< . =" "<leqslantdot>")
+  ("< . = var" "<leqdot>")
+  ("< = ." "<leqslantdot>")
+  ("< = . var" "<leqdot>")
+  ("< = var ." "<leqdot>")
   (". >" "<gtrdot>")
-  ("< = ." "<lesseqdot>")
-  (". > =" "<gtreqdot>")
+  (". > =" "<dotgeqslant>")
+  (". > = var" "<dotgeq>")
 
   ("< >" "<lessgtr>")
   ("< > var" "<diamondsuit>")
@@ -646,53 +665,95 @@
 
   ("< var var" "<subset>")
   ("> var var" "<supset>")
+  ("< var var . ." "<subset><cdots><subset>")
+  ("> var var . ." "<supset><cdots><supset>")
   ("< var var /" "<nsubset>")
   ("> var var /" "<nsupset>")
   ("< var var =" "<subseteq>")
   ("> var var =" "<supseteq>")
+  ("< var var = . ." "<subseteq><cdots><subseteq>")
+  ("> var var = . ." "<supseteq><cdots><supseteq>")
   ("< var var = /" "<nsubseteq>")
   ("> var var = /" "<nsupseteq>")
   ("< var var = var" "<subseteqq>")
   ("> var var = var" "<supseteqq>")
+  ("< var var = var . ." "<subseteqq><cdots><subseteqq>")
+  ("> var var = var . ." "<supseteqq><cdots><supseteqq>")
   ("< var var = /" "<nsubseteq>")
   ("> var var = /" "<nsupseteq>")
   ("< var var = var /" "<nsubseteqq>")
   ("> var var = var /" "<nsupseteqq>")
   ("< var var = / var" "<subsetneq>")
   ("> var var = / var" "<supsetneq>")
+  ("< var var = / var . ." "<subsetneq><cdots><subsetneq>")
+  ("> var var = / var . ." "<supsetneq><cdots><supsetneq>")
   ("< var var = / var var" "<varsubsetneq>")
   ("> var var = / var var" "<varsupsetneq>")
+  ("< var var = / var var . ." "<varsubsetneq><cdots><varsubsetneq>")
+  ("> var var = / var var . ." "<varsupsetneq><cdots><varsupsetneq>")
   ("< var var = var / var" "<subsetneqq>")
   ("> var var = var / var" "<supsetneqq>")
+  ("< var var = var / var . ." "<subsetneqq><cdots><subsetneqq>")
+  ("> var var = var / var . ." "<supsetneqq><cdots><supsetneqq>")
   ("< var var = var / var var" "<varsubsetneqq>")
   ("> var var = var / var var" "<varsupsetneqq>")
+  ("< var var = var / var var . ." "<varsubsetneqq><cdots><varsubsetneqq>")
+  ("> var var = var / var var . ." "<varsupsetneqq><cdots><varsupsetneqq>")
   ("< var var +" "<subsetplus>")
   ("> var var +" "<supsetplus>")
+  ("< var var + . ." "<subsetplus><cdots><subsetplus>")
+  ("> var var + . ." "<supsetplus><cdots><supsetplus>")
   ("< var var + =" "<subsetpluseq>")
   ("> var var + =" "<supsetpluseq>")
   ("< var var = +" "<subsetpluseq>")
   ("> var var = +" "<supsetpluseq>")
+  ("< var var + = . ." "<subsetpluseq><cdots><subsetpluseq>")
+  ("> var var + = . ." "<supsetpluseq><cdots><supsetpluseq>")
+  ("< var var = + . ." "<subsetpluseq><cdots><subsetpluseq>")
+  ("> var var = + . ." "<supsetpluseq><cdots><supsetpluseq>")
   ("< var var ~" "<subsetsim>")
   ("> var var ~" "<supsetsim>")
+  ("< var var ~ . ." "<subsetsim><cdots><subsetsim>")
+  ("> var var ~ . ." "<supsetsim><cdots><supsetsim>")
 
   ("< var var var" "<prec>")
   ("> var var var" "<succ>")
+  ("< var var var . ." "<prec><cdots><prec>")
+  ("> var var var . ." "<succ><cdots><succ>")
   ("< var var var /" "<nprec>")
   ("> var var var /" "<nsucc>")
   ("< var var var =" "<preccurlyeq>")
   ("> var var var =" "<succcurlyeq>")
+  ("< var var var = . ." "<preccurlyeq><cdots><preccurlyeq>")
+  ("> var var var = . ." "<succcurlyeq><cdots><succcurlyeq>")
   ("< var var var = /" "<npreccurlyeq>")
   ("> var var var = /" "<nsucccurlyeq>")
   ("< var var var = var" "<preceq>")
   ("> var var var = var" "<succeq>")
+  ("< var var var = var . ." "<preceq><cdots><preceq>")
+  ("> var var var = var . ." "<succeq><cdots><succeq>")
   ("< var var var = var /" "<npreceq>")
   ("> var var var = var /" "<nsucceq>")
-  ("< var var var = var / var" "<precneqq>")
-  ("> var var var = var / var" "<succneqq>")
+  ("< var var var = var / var" "<precneq>")
+  ("> var var var = var / var" "<succneq>")
+  ("< var var var = var var" "<preceqq>")
+  ("> var var var = var var" "<succeqq>")
+  ("< var var var = var var . ." "<preceqq><cdots><preceqq>")
+  ("> var var var = var var . ." "<succeqq><cdots><succeqq>")
+  ("< var var var = var var /" "<npreceqq>")
+  ("> var var var = var var /" "<nsucceqq>")
+  ("< var var var = var var / var" "<precneqq>")
+  ("> var var var = var var / var" "<succneqq>")
+  ("< var var var = var var / var var" "<precvertneqq>")
+  ("> var var var = var var / var var" "<succvertneqq>")
   ("< var var var ~" "<precsim>")
   ("> var var var ~" "<succsim>")
   ("< var var var ~ ~" "<precapprox>")
   ("> var var var ~ ~" "<succapprox>")
+  ("< var var var ~ . ." "<precsim><cdots><precsim>")
+  ("> var var var ~ . ." "<succsim><cdots><succsim>")
+  ("< var var var ~ ~ . ." "<precapprox><cdots><precapprox>")
+  ("> var var var ~ ~ . ." "<succapprox><cdots><succapprox>")
   ("< var var var ~ /" "<nprecsim>")
   ("> var var var ~ /" "<nsuccsim>")
   ("< var var var ~ / var" "<precnsim>")
@@ -702,20 +763,38 @@
   ("< var var var ~ ~ / var" "<precnapprox>")
   ("> var var var ~ ~ / var" "<succnapprox>")
   ("< var var var ." "<precdot>")
-  ("< var var var = ." "<preceqdot>")
+  ("< var var var . =" "<preccurlyeqdot>")
+  ("< var var var . = var" "<preceqdot>")
+  ("< var var var = ." "<preccurlyeqdot>")
+  ("< var var var = var ." "<preceqdot>")
+  ("< var var var = . var" "<preceqdot>")
   ("< . var" "<precdot>")
+  ("< . var =" "<preccurlyeqdot>")
+  ("< . var = var" "<preceqdot>")
+  ("< . = var var" "<preccurlyeqdot>")
+  ("< . = var var var" "<preceqdot>")
   (". > var" "<dotsucc>")
-  ("< . var =" "<preceqdot>")
-  (". > var =" "<dotsucceq>")
+  (". > var =" "<dotsucccurlyeq>")
+  (". > var = var" "<dotsucceq>")
+  (". > = var var" "<dotsucccurlyeq>")
+  (". > = var var var" "<dotsucceq>")
 
   ("< < var" "<precprec>")
   ("< < < var" "<precprecprec>")
   ("> > var" "<succsucc>")
   ("> > > var" "<succsuccsucc>")
+  ("< < var . ." "<precprec><cdots><precprec>")
+  ("> > var . ." "<succsucc><cdots><succsucc>")
+  ("< < < var . ." "<precprecprec><cdots><precprecprec>")
+  ("> > > var . ." "<succsuccsucc><cdots><succsuccsucc>")
   ("< < var =" "<precpreceq>")
   ("< < < var =" "<precprecpreceq>")
   ("> > var =" "<succsucceq>")
   ("> > > var =" "<succsuccsucceq>")
+  ("< < var = . ." "<precpreceq><cdots><precpreceq>")
+  ("> > var = . ." "<succsucceq><cdots><succsucceq>")
+  ("< < < var = . ." "<precprecpreceq><cdots><precprecpreceq>")
+  ("> > > var = . ." "<succsuccsucceq><cdots><succsuccsucceq>")
   ("< < var /" "<nprecprec>")
   ("< < < var /" "<nprecprecprec>")
   ("> > var /" "<nsuccsucc>")
@@ -727,71 +806,118 @@
 
   ("< var var var var" "<sqsubset>")
   ("> var var var var" "<sqsupset>")
+  ("< var var var var . ." "<sqsubset><cdots><sqsubset>")
+  ("> var var var var . ." "<sqsupset><cdots><sqsupset>")
   ("< var var var var /" "<nsqsubset>")
   ("> var var var var /" "<nsqsupset>")
   ("< var var var var =" "<sqsubseteq>")
   ("> var var var var =" "<sqsupseteq>")
+  ("< var var var var = . ." "<sqsubseteq><cdots><sqsubseteq>")
+  ("> var var var var = . ." "<sqsupseteq><cdots><sqsupseteq>")
+  ("< var var var var = var" "<sqsubseteqq>")
+  ("> var var var var = var" "<sqsupseteqq>")
+  ("< var var var var = var . ." "<sqsubseteqq><cdots><sqsubseteqq>")
+  ("> var var var var = var . ." "<sqsupseteqq><cdots><sqsupseteqq>")
   ("< var var var var = /" "<nsqsubseteq>")
   ("> var var var var = /" "<nsqsupseteq>")
+  ("< var var var var = / var" "<sqsubsetneq>")
+  ("> var var var var = / var" "<sqsupsetneq>")
+  ("< var var var var = / var var" "<varsqsubsetneq>")
+  ("> var var var var = / var var" "<varsqsupsetneq>")
+  ("< var var var var = var /" "<nsqsubseteqq>")
+  ("> var var var var = var /" "<nsqsupseteqq>")
+  ("< var var var var = var / var" "<sqsubsetneqq>")
+  ("> var var var var = var / var" "<sqsupsetneqq>")
+  ("< var var var var = var / var var" "<varsqsubsetneqq>")
+  ("> var var var var = var / var var" "<varsqsupsetneqq>")
 
   ("< < var var" "<Subset>")
   ("> > var var" "<Supset>")
+  ("< < var var . ." "<Subset><cdots><Subset>")
+  ("> > var var . ." "<Supset><cdots><Supset>")
 
-  ("< var var var var var" (math-bracket-open "<langle>" "<rangle>" 'default))
-  ("> var var var var var" (math-bracket-close "<rangle>" "<langle>" 'default))
+  ("< var var var var var" "<leangle>")
+  ("> var var var var var" "<geangle>")
+  ("< var var var var var =" "<leqangle>")
+  ("> var var var var var =" "<geqangle>")
+  
+  ("< var var var var var var" (math-bracket-open "<langle>" "<rangle>" 'default))
+  ("> var var var var var var" (math-bracket-close "<rangle>" "<langle>" 'default))
   ("< < var var var" (math-bracket-open "<llangle>" "<rrangle>" 'default))
   ("> > var var var" (math-bracket-close "<rrangle>" "<llangle>" 'default))
 
+  ("- < var" "<lebar>")
+  ("> - var" "<gebar>")
+  
   ("- >" "<rightarrow>")
   ("- > var" "<downarrow>")
   ("- > var var" "<uparrow>")
   ("- > var var var" "<searrow>")
   ("- > var var var var" "<nearrow>")
+  ("- > . ." "<rightarrow><cdots><rightarrow>")
   ("< -" "<leftarrow>")
   ("< - var" "<uparrow>")
   ("< - var var" "<downarrow>")
   ("< - var var var" "<nwarrow>")
   ("< - var var var var" "<swarrow>")
+  ("< - . ." "<leftarrow><cdots><leftarrow>")
   ("< - >" "<leftrightarrow>")
   ("< - > var" "<updownarrow>")
+  ("< - > . ." "<leftrightarrow><cdots><leftrightarrow>")
   ("- -" "<longminus>")
   ("- - var" "<longdownminus>")
   ("- - >" "<longrightarrow>")
   ("- - > var" "<longdownarrow>")
   ("- - > var var" "<longuparrow>")
+  ("- - > . ." "<longrightarrow><cdots><longrightarrow>")
   ("< - -" "<longleftarrow>")
   ("< - - var" "<longuparrow>")
   ("< - - var var" "<longdownarrow>")
+  ("< - - . ." "<longleftarrow><cdots><longleftarrow>")
   ("< - - >" "<longleftrightarrow>")
   ("< - - > var" "<longupdownarrow>")
+  ("< - - > . ." "<longleftrightarrow><cdots><longleftrightarrow>")
   ("= >" "<Rightarrow>")
   ("= > var" "<Downarrow>")
   ("= > var var" "<Uparrow>")
+  ("= > . ." "<Rightarrow><cdots><Rightarrow>")
   ("< = var var var" "<Leftarrow>")
+  ("< = var var var . ." "<Leftarrow><cdots><Leftarrow>")
   ("< = >" "<Leftrightarrow>")
   ("< = > var" "<Updownarrow>")
+  ("< = > . ." "<Leftrightarrow><cdots><Leftrightarrow>")
   ("= =" "<longequal>")
   ("= = var" "<longdownequal>")
   ("= = >" "<Longrightarrow>")
   ("= = > var" "<Longdownarrow>")
   ("= = > var var" "<Longuparrow>")
+  ("= = > . ." "<Longrightarrow><cdots><Longrightarrow>")
   ("< = =" "<Longleftarrow>")
   ("< = = var" "<Longuparrow>")
   ("< = = var var" "<Longdownarrow>")
+  ("< = = . ." "<Longleftarrow><cdots><Longleftarrow>")
   ("< = = >" "<Longleftrightarrow>")
   ("< = = > var" "<Longupdownarrow>")
-  ("- /" "<rightharpoondown>")
-  ("- / var" "<rightharpoonup>")
-  ("- / var var" "<downharpoonleft>")
-  ("- / var var var" "<downharpoonright>")
-  ("- / var var var var" "<upharpoonright>")
-  ("- / var var var var var" "<upharpoonleft>")
-  ("/ -" "<leftharpoonup>")
-  ("/ - var" "<leftharpoondown>")
-  ("/ - var var" "<upharpoonright>")
-  ("/ - var var var" "<upharpoonleft>")
-  ("/ - var var var var" "<downharpoonleft>")
-  ("/ - var var var var var" "<downharpoonright>")
+  ("< = = > . ." "<Longleftrightarrow><cdots><Longleftrightarrow>")
+  ("- / var" "<rightharpoondown>")
+  ("- / var var" "<rightharpoonup>")
+  ("- / var var var" "<downharpoonleft>")
+  ("- / var var var var" "<downharpoonright>")
+  ("- / var var var var var" "<upharpoonright>")
+  ("- / var var var var var var" "<upharpoonleft>")
+  ("/ - var" "<leftharpoonup>")
+  ("/ - var var" "<leftharpoondown>")
+  ("/ - var var var" "<upharpoonright>")
+  ("/ - var var var var" "<upharpoonleft>")
+  ("/ - var var var var var" "<downharpoonleft>")
+  ("/ - var var var var var var" "<downharpoonright>")
+  ("- - / var" "<longrightharpoondown>")
+  ("- - / var var" "<longrightharpoonup>")
+  ("/ - - var" "<longleftharpoonup>")
+  ("/ - - var var" "<longleftharpoondown>")
+  ("/ - var -" "<longleftharpoonup>")
+  ("/ - var - var" "<longleftharpoondown>")
+  ("/ - var var -" "<longleftharpoondown>")
   ("| - >" "<mapsto>")
   ("| - > var" "<hookrightarrow>")
   ("| - > var var" "<mapsdown>")
@@ -831,11 +957,14 @@
   ("~ >" "<rightsquigarrow>")
   ("~ > var" "<downsquigarrow>")
   ("~ > var var" "<upsquigarrow>")
+  ("~ > . ." "<rightsquigarrow><cdots><rightsquigarrow>")
   ("< ~ var" "<leftsquigarrow>")
   ("< ~ var var" "<upsquigarrow>")
   ("< ~ var var var" "<downsquigarrow>")
+  ("< ~ . ." "<leftsquigarrow><cdots><leftsquigarrow>")
   ("< ~ >" "<leftrightsquigarrow>")
   ("< ~ > var" "<updownsquigarrow>")
+  ("< ~ > . ." "<leftrightsquigarrow><cdots><leftrightsquigarrow>")
   ("< - <" "<leftarrowtail>")
   ("> - >" "<rightarrowtail>")
   ("- > - >" "<rightrightarrows>")
@@ -846,8 +975,16 @@
   ("< - < - var var" "<downdownarrows>")
   ("- > < -" "<rightleftarrows>")
   ("- > < - var" "<rightleftharpoons>")
+  ("- - > < -" "<longrightleftarrows>")
+  ("- - > < - var" "<longrightleftharpoons>")
+  ("- - > < - -" "<longrightleftarrows>")
+  ("- - > < - - var" "<longrightleftharpoons>")
   ("< - - > var var" "<leftrightarrows>")
   ("< - - > var var var" "<leftrightharpoons>")
+  ("< - - - >" "<longleftrightarrows>")
+  ("< - - - > var" "<longleftrightharpoons>")
+  ("< - - - - >" "<longleftrightarrows>")
+  ("< - - - - > var" "<longleftrightharpoons>")
   ("- > >" "<twoheadrightarrow>")
   ("< < -" "<twoheadleftarrow>")
   ("- - > >" "<longtwoheadrightarrow>")
@@ -900,60 +1037,131 @@
 
   ("- ^" (make-long-arrow "<minus>"))
   ("- > ^" (make-long-arrow "<rightarrow>"))
+  ("- @ ^" (make-long-arrow "<multimap>"))
   ("< - ^" (make-long-arrow "<leftarrow>"))
   ("< - > ^" (make-long-arrow "<leftrightarrow>"))
   ("| - > ^" (make-long-arrow "<mapsto>"))
   ("| var - > ^" (make-long-arrow "<mapsto>"))
+  ("| - > var ^" (make-long-arrow "<hookrightarrow>"))
+  ("| var - > var ^" (make-long-arrow "<hookrightarrow>"))
   ("< - | ^" (make-long-arrow "<mapsfrom>"))
+  ("< - | var ^" (make-long-arrow "<hookleftarrow>"))
+  ("- > > ^" (make-long-arrow "<twoheadrightarrow>"))
+  ("< < - ^" (make-long-arrow "<twoheadleftarrow>"))
+  ("- / var ^" (make-long-arrow "<rightharpoondown>"))
+  ("- / var var ^" (make-long-arrow "<rightharpoonup>"))
+  ("/ - var ^" (make-long-arrow "<leftharpoonup>"))
+  ("/ - var var ^" (make-long-arrow "<leftharpoondown>"))
   ("= ^" (make-long-arrow "<equal>"))
   ("= > ^" (make-long-arrow "<Rightarrow>"))
   ("< = ^" (make-long-arrow "<Leftarrow>"))
   ("< = > ^" (make-long-arrow "<Leftrightarrow>"))
+  ("@ - ^" (make-long-arrow "<mapmulti>"))
+
   ("- - ^" (make-long-arrow "<minus>"))
   ("- - > ^" (make-long-arrow "<rightarrow>"))
+  ("- - @ ^" (make-long-arrow "<multimap>"))
   ("< - - ^" (make-long-arrow "<leftarrow>"))
   ("< - - > ^" (make-long-arrow "<leftrightarrow>"))
+  ("< - - > var var var ^" (make-long-arrow "<leftrightharpoons>"))
+  ("< - - - > var ^" (make-long-arrow "<leftrightharpoons>"))
+  ("< - - - - > var ^" (make-long-arrow "<leftrightharpoons>"))
+  ("- > < - var ^" (make-long-arrow "<rightleftharpoons>"))
+  ("- - > < - var ^" (make-long-arrow "<rightleftharpoons>"))
+  ("- - > < - - var ^" (make-long-arrow "<rightleftharpoons>"))
   ("| - - > ^" (make-long-arrow "<mapsto>"))
   ("| var - - > ^" (make-long-arrow "<mapsto>"))
+  ("| - - > var ^" (make-long-arrow "<hookrightarrow>"))
+  ("| var - - > var ^" (make-long-arrow "<hookrightarrow>"))
   ("< - - | ^" (make-long-arrow "<mapsfrom>"))
+  ("< - - | var ^" (make-long-arrow "<hookleftarrow>"))
+  ("- - > > ^" (make-long-arrow "<twoheadrightarrow>"))
+  ("< < - - ^" (make-long-arrow "<twoheadleftarrow>"))
+  ("- - / var ^" (make-long-arrow "<rightharpoondown>"))
+  ("- - / var var ^" (make-long-arrow "<rightharpoonup>"))
+  ("/ - - var ^" (make-long-arrow "<leftharpoonup>"))
+  ("/ - var - ^" (make-long-arrow "<leftharpoonup>"))
+  ("/ - - var var ^" (make-long-arrow "<leftharpoondown>"))
+  ("/ - var - var ^" (make-long-arrow "<leftharpoondown>"))
+  ("/ - var var - ^" (make-long-arrow "<leftharpoondown>"))
   ("= = ^" (make-long-arrow "<equal>"))
   ("= = > ^" (make-long-arrow "<Rightarrow>"))
   ("< = = ^" (make-long-arrow "<Leftarrow>"))
   ("< = = > ^" (make-long-arrow "<Leftrightarrow>"))
+  ("@ - - ^" (make-long-arrow "<mapmulti>"))
 
   ("- _" (make-long-arrow* "<minus>"))
   ("- > _" (make-long-arrow* "<rightarrow>"))
+  ("- @ _" (make-long-arrow* "<multimap>"))
   ("< - _" (make-long-arrow* "<leftarrow>"))
   ("< - > _" (make-long-arrow* "<leftrightarrow>"))
   ("| - > _" (make-long-arrow* "<mapsto>"))
   ("| var - > _" (make-long-arrow* "<mapsto>"))
+  ("| - > var _" (make-long-arrow* "<hookrightarrow>"))
+  ("| var - > var _" (make-long-arrow* "<hookrightarrow>"))
   ("< - | _" (make-long-arrow* "<mapsfrom>"))
+  ("< - | var _" (make-long-arrow* "<hookleftarrow>"))
+  ("- > > _" (make-long-arrow* "<twoheadrightarrow>"))
+  ("< < - _" (make-long-arrow* "<twoheadleftarrow>"))
+  ("- / var _" (make-long-arrow* "<rightharpoondown>"))
+  ("- / var var _" (make-long-arrow* "<rightharpoonup>"))
+  ("/ - var _" (make-long-arrow* "<leftharpoonup>"))
+  ("/ - var var _" (make-long-arrow* "<leftharpoondown>"))
   ("= _" (make-long-arrow* "<equal>"))
   ("= > _" (make-long-arrow* "<Rightarrow>"))
   ("< = _" (make-long-arrow* "<Leftarrow>"))
   ("< = > _" (make-long-arrow* "<Leftrightarrow>"))
+  ("@ - _" (make-long-arrow* "<mapmulti>"))
+
   ("- - _" (make-long-arrow* "<minus>"))
   ("- - > _" (make-long-arrow* "<rightarrow>"))
+  ("- - @ _" (make-long-arrow* "<multimap>"))
   ("< - - _" (make-long-arrow* "<leftarrow>"))
   ("< - - > _" (make-long-arrow* "<leftrightarrow>"))
+  ("< - - > var var var _" (make-long-arrow* "<leftrightharpoons>"))
+  ("< - - - > var _" (make-long-arrow* "<leftrightharpoons>"))
+  ("< - - - - > var _" (make-long-arrow* "<leftrightharpoons>"))
+  ("- > < - var _" (make-long-arrow* "<rightleftharpoons>"))
+  ("- - > < - var _" (make-long-arrow* "<rightleftharpoons>"))
+  ("- - > < - - var _" (make-long-arrow* "<rightleftharpoons>"))
   ("| - - > _" (make-long-arrow* "<mapsto>"))
   ("| var - - > _" (make-long-arrow* "<mapsto>"))
+  ("| - - > var _" (make-long-arrow* "<hookrightarrow>"))
+  ("| var - - > var _" (make-long-arrow* "<hookrightarrow>"))
   ("< - - | _" (make-long-arrow* "<mapsfrom>"))
+  ("< - - | var _" (make-long-arrow* "<hookleftarrow>"))
+  ("- - > > _" (make-long-arrow* "<twoheadrightarrow>"))
+  ("< < - - _" (make-long-arrow* "<twoheadleftarrow>"))
+  ("- - / var _" (make-long-arrow* "<rightharpoondown>"))
+  ("- - / var var _" (make-long-arrow* "<rightharpoonup>"))
+  ("/ - - var _" (make-long-arrow* "<leftharpoonup>"))
+  ("/ - var - _" (make-long-arrow* "<leftharpoonup>"))
+  ("/ - - var var _" (make-long-arrow* "<leftharpoondown>"))
+  ("/ - var - var _" (make-long-arrow* "<leftharpoondown>"))
+  ("/ - var var - _" (make-long-arrow* "<leftharpoondown>"))
   ("= = _" (make-long-arrow* "<equal>"))
   ("= = > _" (make-long-arrow* "<Rightarrow>"))
   ("< = = _" (make-long-arrow* "<Leftarrow>"))
   ("< = = > _" (make-long-arrow* "<Leftrightarrow>"))
+  ("@ - - _" (make-long-arrow* "<mapmulti>"))
 
   ("@" "<circ>")
   ("@ /" "<varnothing>")
   ("@ +" "<oplus>")
+  ("@ + . ." "<oplus><cdots><oplus>")
   ("@ -" "<ominus>")
   ("@ - var" "<mapmulti>")
+  ("@ - var -" "<longmapmulti>")
+  ("@ - -" "<longmapmulti>")
   ("@ ." "<odot>")
+  ("@ . ." "<circ><cdots><circ>")
   ("@ :" "<oover>")
   ("@ x" "<otimes>")
+  ("@ x . ." "<otimes><cdots><otimes>")
   ("@ *" "<otimes>")
+  ("@ * . ." "<otimes><cdots><otimes>")
   ("@ * var" "<oast>")
+  ("@ x var . ." "<oast><cdots><oast>")
   ("@ R" "<circledR>")
   ("@ S" "<circledS>")
   ("@ / var" "<oslash>")
@@ -986,19 +1194,40 @@
   ("@ var var var var var" "<blacktriangle>")
 
   ("= var" "<asymp>")
+  ("= var . ." "<asymp><cdots><asymp>")
   ("= var var" "<equiv>")
+  ("= var var . ." "<equiv><cdots><equiv>")
   ("= var var var" "<asympasymp>")
+  ("= var var var . ." "<asympasymp><cdots><asympasymp>")
   ("= var var var var" "<simsim>")
+  ("= var var var var . ." "<simsim><cdots><simsim>")
   ("= var var var var var" "<downequal>")
+  ("= . ." "=<cdots>=")
+  ("= :" "<backassign>")
   ("~" "<sim>")
   ("~ var" "<backsim>")
+  ("~ . ." "<sim><cdots><sim>")
   ("~ ~" "<approx>")
+  ("~ ~ . ." "<approx><cdots><approx>")
   ("~ ~ var" "<Bumpeq>")
+  ("~ ~ var . ." "<Bumpeq><cdots><Bumpeq>")
   ("~ ~ -" "<approxeq>")
+  ("~ ~ - . ." "<approxeq><cdots><approxeq>")
+  ("~ ~ - /" "<napproxeq>")
+  ("~ ~ =" "<approxeq>")
+  ("~ ~ = . ." "<approxeq><cdots><approxeq>")
+  ("~ ~ = /" "<napproxeq>")
+  ("~ ~ ~" "<triplesim>")
+  ("~ ~ ~ . ." "<triplesim><cdots><triplesim>")
+  ("~ ~ ~ /" "<ntriplesim>")
   ("~ -" "<simeq>")
+  ("~ - . ." "<simeq><cdots><simeq>")
   ("~ - var" "<backsimeq>")
+  ("~ - var . ." "<backsimeq><cdots><backsimeq>")
   ("~ - var var" "<bumpeq>")
+  ("~ - var var . ." "<bumpeq><cdots><bumpeq>")
   ("~ =" "<cong>")
+  ("~ = . ." "<cong><cdots><cong>")
   ("= /" "<neq>")
   ("= var /" "<nasymp>")
   ("= var var /" "<nequiv>")
@@ -1037,25 +1266,39 @@
   ("# var var" "<natural>")
   ("# var var var" "<flat>")
   ("&" "<wedge>")
+  ("& . ." "<wedge><cdots><wedge>")
   ("& var" "<cap>")
+  ("& var . ." "<cap><cdots><cap>")
   ("& var var" "<sqcap>")
+  ("& var var . ." "<sqcap><cdots><sqcap>")
   ("& var var var" "<product>")
+  ("& var var var . ." "<product><cdots><product>")
   ("& var var var var" "<curlywedge>")
+  ("& var var var var var . ." "<curlywedge><cdots><curlywedge>")
   ("& var var var var var" "<curlywedgeuparrow>")
   ("& var var var var var var" "<curlywedgedownarrow>")
   ("& var var var var var var var" "&")
   ("- &" "<barwedge>")
+  ("- & . ." "<barwedge><cdots><barwedge>")
   ("%" "<vee>")
+  ("% . ." "<vee><cdots><vee>")
   ("% var" "<cup>")
+  ("% var . ." "<cup><cdots><cup>")
   ("% var +" "<uplus>")
+  ("% var + . ." "<uplus><cdots><uplus>")
+  ("% var + +" "<uplus><cdots><uplus>")
   ("% var var" "<sqcup>")
+  ("% var var . ." "<sqcup><cdots><sqcup>")
   ("% var var var" "<amalg>")
+  ("% var var var . ." "<amalg><cdots><amalg>")
   ("% var var var var" "<curlyvee>")
+  ("% var var var var . ." "<curlyvee><cdots><curlyvee>")
   ("% var var var var var" "<curlyveedownarrow>")
   ("% var var var var var var" "<curlyveeuparrow>")
   ("% var var var var var var var" "<permil>")
   ("% var var var var var var var var" "%")
   ("% -" "<veebar>")
+  ("% - . ." "<veebar><cdots><veebar>")
 
   ("| /" "<nmid>")
   ("| var" "|")
@@ -1064,7 +1307,7 @@
   ("| var var/" "<nmid>")
   ("| var var var" "<shortmid>")
   ("| var var var /" "<nshortmid>")
-  ("| var var var var" "<divides>")
+  ("| var var var var" "<barsuchthat>")
   ("| var var var var var" "<divides>")
   ("| | var" "<||>")
   ("| | var /" "<nparallel>")
@@ -1127,57 +1370,91 @@
   ("| | - var /" "<nVdash>")
   ("| | - /" "<nVdash>")
   ("| | var - /" "<nVdash>")
+  ("| | | - var /" "<nVvdash>")
+  ("| | | - /" "<nVvdash>")
+  ("| | | var - /" "<nVvdash>")
   ("- | var /" "<ndashv>")
   ("- | /" "<ndashv>")
   ("- | var | /" "<ndashV>")
   ("- | | var /" "<ndashV>")
   ("- | | /" "<ndashV>")
+  ("- | | | var /" "<ndashVv>")
+  ("- | | | /" "<ndashVv>")
   ("| = var /" "<nvDash>")
   ("| = /" "<nvDash>")
   ("| var = /" "<nvDash>")
   ("| | = var /" "<nVDash>")
   ("| | = /" "<nVDash>")
   ("| | var = /" "<nVDash>")
+  ("| | | = var /" "<nVvDash>")
+  ("| | | = /" "<nVvDash>")
+  ("| | | var = /" "<nVvDash>")
   ("= | var /" "<nDashv>")
   ("= | /" "<nDashv>")
   ("= | var | /" "<nDashV>")
   ("= | | var /" "<nDashV>")
   ("= | | /" "<nDashV>")
+  ("= | | | var /" "<nDashVv>")
+  ("= | | | /" "<nDashVv>")
 
   ("< | var" "<vartriangleleft>")
-  ("< | var var" "<blacktriangleleft>")
   ("< | var /" "<ntriangleleft>")
   ("< | var =" "<trianglelefteqslant>")
   ("< | var = /" "<ntrianglelefteqslant>")
   ("< | var = var" "<trianglelefteq>")
   ("< | var = var /" "<ntrianglelefteq>")
+  ("< | var var" "<blacktriangleleft>")
+  ("< | var var /" "<nblacktriangleleft>")
+  ("< | var var =" "<blacktrianglelefteqslant>")
+  ("< | var var = /" "<nblacktrianglelefteqslant>")
+  ("< | var var = var" "<blacktrianglelefteq>")
+  ("< | var var = var /" "<nblacktrianglelefteq>")
   ("| > var" "<vartriangleright>")
-  ("| > var var" "<blacktriangleright>")
   ("| > var /" "<ntriangleright>")
   ("| > var =" "<trianglerighteqslant>")
   ("| > var = /" "<ntrianglerighteqslant>")
   ("| > var = var" "<trianglerighteq>")
   ("| > var = var /" "<ntrianglerighteq>")
+  ("| > var var" "<blacktriangleright>")
+  ("| > var var /" "<nblacktriangleright>")
+  ("| > var var =" "<blacktrianglerighteqslant>")
+  ("| > var var = /" "<nblacktrianglerighteqslant>")
+  ("| > var var = var" "<blacktrianglerighteq>")
+  ("| > var var = var /" "<nblacktrianglerighteq>")
   ("| var >" "<vartriangleright>")
-  ("| var > var" "<blacktriangleright>")
   ("| var > /" "<ntriangleright>")
   ("| var > =" "<trianglerighteqslant>")
   ("| var > = /" "<ntrianglerighteqslant>")
   ("| var > = var" "<trianglerighteq>")
   ("| var > = var /" "<ntrianglerighteq>")
+  ("| var > var" "<blacktriangleright>")
+  ("| var > var /" "<nblacktriangleright>")
+  ("| var > var =" "<blacktrianglerighteqslant>")
+  ("| var > var = /" "<nblacktrianglerighteqslant>")
+  ("| var > var = var" "<blacktrianglerighteq>")
+  ("| var > var = var /" "<nblacktrianglerighteq>")
 
   ("+ var" "<kreuz>")
   ("+ var var" "<dag>")
   ("+ var var var" "<ddag>")
   ("+ var var var var" "<noplus>")
+  ("+ . ." "+<cdots>+")
   ("+ +" "+<cdots>+")
   ("+ -" "<pm>")
   ("- +" "<mp>")
+  ("+ - . ." "<pm><cdots><pm>")
+  ("- + . ." "<mp><cdots><mp>")
   ("@ =" "<circeq>")
   ("@ = var" "<triangleq>")
   ("= @" "<eqcirc>")
+  ("- . ." "-<cdots>-")
   ("- @" "<multimap>")
+  ("- - @" "<longmultimap>")
   (". =" "<doteq>")
+  (". +" "<dotplus>")
+  (". -" "<dotminus>")
+  (". *" "<dottimes>")
+  (". * var" "<dotast>")
   (". ." "<ldots>")
   (". . var" "<cdots>")
   (". . var !" "<cdotslim>")
@@ -1188,6 +1465,8 @@
   (":" ":")
   (": var" "<of>")
   (": var var" "<over>")
+  (": var var . ." "<over><ldots><over>")
+  (": var var var" "<suchthat>")
   (": :" "<colons>")
   (": >" "<transtype>")
   (": =" "<assign>")
@@ -1196,19 +1475,32 @@
   ("/ var" "<over>")
   ("/ var var" "<div>")
   ("*" "*")
+  ("* . ." "*<cdots>*")
   ("* *" "*<cdots>*")
   ("* var" "<times>")
+  ("* var . ." "<times><cdots><times>")
   ("* var var" "<ast>")
+  ("* var var . ." "<ast><cdots><ast>")
   ("* var var var" "<cdot>")
+  ("* var var var . ." "<cdot><cdots><cdot>")
   ("* var var var var" "<exterior>")
+  ("* var var var var . ." "<exterior><cdots><exterior>")
   ("* var var var var var" "<star>")
   ("* &" "<exterior>")
   ("| * var" "<ltimes>")
+  ("| * var var" "<ttimes>")
+  ("| * var var var" "<btimes>")
   ("| * var |" "<join>")
   ("| var *" "<ltimes>")
+  ("| var * var" "<ttimes>")
+  ("| var * var var" "<btimes>")
   ("| var * |" "<join>")
   ("* | var" "<rtimes>")
+  ("* | var var" "<btimes>")
+  ("* | var var var" "<ttimes>")
   ("* var var |" "<rtimes>")
+  ("* var var | var" "<btimes>")
+  ("* var var | var var" "<ttimes>")
   ("! var" "<neg>")
 
   ("math:greek a" "<alpha>")
@@ -1548,7 +1840,7 @@
   ("math:bold:cal g" "<b-cal-g>")
   ("math:bold:cal h" "<b-cal-h>")
   ("math:bold:cal i" "<b-cal-i>")
-  ("math:bold:cal h" "<b-cal-j>")
+  ("math:bold:cal j" "<b-cal-j>")
   ("math:bold:cal k" "<b-cal-k>")
   ("math:bold:cal l" "<b-cal-l>")
   ("math:bold:cal m" "<b-cal-m>")
@@ -1737,6 +2029,13 @@
   ("Y Y" "<bbb-Y>")
   ("Z Z" "<bbb-Z>")
 
+  ;;("d d" "<mathd>")
+  ;;("d d var" "<partial>")
+  ;;("e e" "<mathe>")
+  ;;("g g" "<matheuler>")
+  ;;("i i" "<mathi>")
+  ;;("l l" "<mathlambda>")
+  ;;("p p" "<mathpi>")
   ("R E" "<Re>")
   ("I M" "<Im>"))
 
@@ -1834,6 +2133,8 @@
   ("T var var var" "<bot>")
   ("T var var var var" "<leftthreetimes>")
   ("T var var var var var" "<rightthreetimes>")
+  ("T var var var var var var" "<lefttimesthree>")
+  ("T var var var var var var var" "<righttimesthree>")
   ("U var" "<Upsilon>")
   ("V var" "<Phi>")
   ("V var var" "<nabla>")
@@ -1841,6 +2142,10 @@
   ("W var var" "<Mho>")
   ("X var" "<Xi>")
   ("Y var" "<Psi>")
+  ("Y var var" "<Ydown>")
+  ("Y var var var" "<Yup>")
+  ("Y var var var var" "<Yleft>")
+  ("Y var var var var var" "<Yright>")
   ("Z var" "<Zeta>"))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
