@@ -452,42 +452,67 @@
             "5em"))))
 
 ;; Pdf ----------
+(define-preference-names "texmacs->pdf:version"
+  ("Default" "default")
+  ("1.4" "1.4")
+  ("1.5" "1.5")
+  ("1.6" "1.6")
+  ("1.7" "1.7"))
 
 (tm-widget (pdf-preferences-widget)
   ===
   (bold (text "TeXmacs -> Pdf/Postscript"))
   ===
   (aligned
-    (meti (hlist // (text "Produce Pdf using native export filter"))
-      (toggle (set-boolean-preference "native pdf" answer)
-              (get-boolean-preference "native pdf")))
-    (meti (hlist // (text "Produce Postscript using native export filter"))
-      (toggle (set-boolean-preference "native postscript" answer)
-              (get-boolean-preference "native postscript")))
-    (meti (hlist // (text "Expand beamer slides"))
+    (assuming (supports-native-pdf?)
+      (meti (hlist // (text "Produce Pdf using native export filter"))
+	(toggle (set-boolean-preference "native pdf" answer)
+		(get-boolean-preference "native pdf"))))
+    (assuming (supports-ghostscript?)
+      (meti (hlist // (text "Produce Postscript using native export filter"))
+	(toggle (set-boolean-preference "native postscript" answer)
+		(get-boolean-preference "native postscript"))))
+   (meti (hlist // (text "Expand beamer slides"))
       (toggle (set-boolean-preference "texmacs->pdf:expand slides" answer)
-              (get-boolean-preference "texmacs->pdf:expand slides")))
-    (meti (hlist // (text "Check exported files for correctness"))
-      (toggle (set-boolean-preference "texmacs->pdf:check" answer)
-              (get-boolean-preference "texmacs->pdf:check")))))
+	      (get-boolean-preference "texmacs->pdf:expand slides"))))
+    (assuming (supports-native-pdf?)
+      (aligned (meti (hlist // (text "Distill encapsulated Pdf files"))
+	(toggle (set-boolean-preference "texmacs->pdf:distill inclusion" answer)
+		(get-boolean-preference "texmacs->pdf:distill inclusion"))))
+      (aligned (meti (hlist // (text "Check exported Pdf files for correctness"))
+	(toggle (set-boolean-preference "texmacs->pdf:check" answer)
+		(get-boolean-preference "texmacs->pdf:check"))))
+      (aligned (item (text "Pdf version number:")
+        (enum (set-preference "texmacs->pdf:version" answer)
+	      '("default" "1.4" "1.5" "1.6" "1.7")
+	      (get-preference "texmacs->pdf:version") "8em")))))
 
 ;; Images ----------
 
-(define-preference-names "texmacs->graphics:format"
-  ("svg" "Svg")
-  ("eps" "Eps")
-  ("png" "Png"))
+(define (pretty-format-list)
+  (let* ((desired-image-format-list '(("svg" "Svg")  ("eps" "Eps")
+           ("png" "Png")("tif" "Tiff") ("jpg" "Jpeg") ("pdf" "Pdf")))
+         (valid-image-format-list 
+           (filter (lambda (x) (file-converter-exists? "x.pdf" (string-append "x." (car x))))
+             desired-image-format-list)))
+   (eval `(define-preference-names "texmacs->image:format" ,@valid-image-format-list))
+   (cadr (apply map list valid-image-format-list))))
 
 (tm-widget (image-preferences-widget)
   ===
   (bold (text "TeXmacs -> Image"))
   ===
   (aligned
-    (item (text "Format:")
-      (enum (set-pretty-preference "texmacs->graphics:format" answer)
-            '("Svg" "Eps" "Png")
-            (get-pretty-preference "texmacs->graphics:format")
-            "5em"))))
+      (item (text "Bitmap resolution (dpi):")
+        (enum (set-preference "texmacs->image:raster-resolution" answer)
+	      '("1200" "600" "300" "150" "")
+	      (get-preference "texmacs->image:raster-resolution")
+	      "5em"))
+      (item (text "Clipboard image format:")
+        (enum (set-pretty-preference "texmacs->image:format" answer)
+	      (pretty-format-list)
+	      (get-pretty-preference "texmacs->image:format")
+	      "5em"))))
 
 ;; All converters ----------
 
@@ -507,7 +532,7 @@
       (tab (text "Verbatim")
         (centered
           (dynamic (verbatim-preferences-widget))))
-      (assuming (and (supports-native-pdf?) (supports-ghostscript?))
+      (assuming (or (supports-native-pdf?) (supports-ghostscript?))
         (tab (text "Pdf")
           (centered
             (dynamic (pdf-preferences-widget)))))
@@ -609,12 +634,19 @@
       (meti (hlist // (text "New style fonts"))
         (toggle (set-boolean-preference "new style fonts" answer)
                 (get-boolean-preference "new style fonts")))
-      (meti (hlist // (text "New bibliography dialogue"))
-        (toggle (set-boolean-preference "gui:new bibliography dialogue" answer)
-                (get-boolean-preference "gui:new bibliography dialogue"))))
+      (meti (hlist // (text "Advanced font customization"))
+        (toggle (set-boolean-preference "advanced font customization" answer)
+                (get-boolean-preference "advanced font customization")))
+      (meti (hlist // (text "New style page breaking"))
+        (toggle (set-boolean-preference "new style page breaking" answer)
+                (get-boolean-preference "new style page breaking"))))
     /// ///
     (vlist
       (aligned
+        (meti (hlist // (text "New bibliography dialogue"))
+          (toggle
+           (set-boolean-preference "gui:new bibliography dialogue" answer)
+           (get-boolean-preference "gui:new bibliography dialogue")))
         (meti (hlist // (text "Program bracket matching"))
           (toggle (set-boolean-preference "prog:highlight brackets" answer)
                   (get-boolean-preference "prog:highlight brackets")))
@@ -624,10 +656,17 @@
         (meti (hlist // (text "Program bracket selections"))
           (toggle (set-boolean-preference "prog:select brackets" answer)
                   (get-boolean-preference "prog:select brackets")))
+        (meti (hlist // (text "Case-insensitive search"))
+          (toggle (set-boolean-preference "case-insensitive-match" answer)
+                  (get-boolean-preference "case-insensitive-match")))
         (assuming (qt-gui?)  ; TODO: recode the dialogue in scheme
           (meti (hlist // (text "Use print dialogue"))
             (toggle (set-boolean-preference "gui:print dialogue" answer)
-                    (get-boolean-preference "gui:print dialogue")))))
+                    (get-boolean-preference "gui:print dialogue"))))
+        (assuming (os-macos?)
+          (meti (hlist // (text "Use unified toolbars"))
+            (toggle (set-boolean-preference "use unified toolbar" answer)
+                    (get-boolean-preference "use unified toolbar")))))
       (glue #f #t 0 0))))
 
 (tm-widget (other-preferences-widget)
